magneticalc.Field_Types

# ``magneticalc`.`Field_Types``

module documentation

Field_Types module.

Function | `field_name_to_type` | Converts a field name to a field type.
Function | `field_type_safe` | A valid field type is passed through, but an invalid field type converts to the default type.
Constant | `FIELD_TYPE_A` | Field type: B-Field.
Constant | `FIELD_TYPE_B` | Map of field types to names.
Variable | `Field_Types_Abbreviations_Map` | Default field type.
Variable | `Field_Types_Names_Map` | Map of field types to abbreviations.

def field_name_to_type(field_name: `str`) -> `int`:

Converts a field name to a field type.

Parameters
field_name: `str` | Field name

Returns
`int` | Field type

def field_type_safe(field_type: `int`) -> `int`:

A valid field type is passed through, but an invalid field type converts to the default type.

Parameters
field_type: `int` | Field type

Returns
`int` | Safe field type

FIELD_TYPE_A: `int` =

Field type: B-Field.

Value
    0

FIELD_TYPE_B: `int` =

Map of field types to names.

Value
    1

Field_Types_Abbreviations_Map =

Default field type.

Field_Types_Names_Map =

Map of field types to abbreviations.